import {
  select,
  scaleOrdinal,
  schemeCategory10
} from 'd3';
import { observeResize } from '@curran/responsive-axes';
import { parallelCoordinates } from './parallelCoordinates';
import { data } from '@ayush-shinde/ev_data'; 

data.forEach((d, i) => {
  d.id = i;
  d.Battery = d.Battery.toString();
  d.Efficiency = d.Efficiency.toString();
  d.Range = d.Range.toString();
});

const columns = [
  'Efficiency',
  'Price',
  'Range',
  'Top_speed',
  'Acceleration'
];
const columnTypes = {
  Battery: 'quantitative',
  Efficiency: 'quantitative',
  Price: 'quantitative',
  Range: 'quantitative',
  Top_speed: 'quantitative',
  Acceleration: 'quantitative'
};
const colorValue = (d) => d.Car_brand;
const idValue = (d) => d.id;

export const main = (container, { state, setState }) => {
  const dimensions = observeResize({
    state,
    setState,
    container,
  });
  if (dimensions === null) return;
  const { width, height } = dimensions;

  if (!state.brushedIntervals) {
    setState((state) => ({
      ...state,
      brushedIntervals: {},
    }));
    return;
  }
  const { brushedIntervals } = state;

  const updateBrushedInterval = ({ column, interval }) => {
    setState((state) => ({
      ...state,
      brushedIntervals: {
        ...state.brushedIntervals,
        [column]: interval,
      },
    }));
  };

  const svg = select(container)
    .selectAll('svg')
    .data([null])
    .join('svg')
    .attr('width', width)
    .attr('height', height)
    .style('background', '#333333');

  svg.call(parallelCoordinates, {
    data: data,
    columns,
    columnTypes,
    colorValue,
    idValue,
    width,
    height,
    brushedIntervals,
    updateBrushedInterval,
  });
};
